QuickWeb Application Development Guidelines
===========================================

Requirements
-------------

In order to develop a web application with `QuickWeb`, know-how with the following topics is recommended:

* Essentials
    * HTML - Defines a web page fundamental structure

* Standard
    * CSS - Defines the page layout and elements properties (themes)

HTML and CSS are the fundamental technology for web presentation.

* Advanced
    * JS (JavaScript) - Application code that will run on the web browser
    * Python - Application code that  will run on the web server


